| Title: | Colour palettes based on classic rock album covers |
|---|---|
| Description: | Colour palettes, scales and fills based on classic rock album covers. |
| Authors: | John MacKintosh [aut, cre] |
| Maintainer: | John MacKintosh <[email protected]> |
| License: | GPL-3 + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-19 06:46:45 UTC |
| Source: | https://github.com/johnmackintosh/rockthemes |
californication palette
californication_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_californication(n, type = "discrete", reverse = FALSE, ...) scale_colour_californication(n, type = "discrete", reverse = FALSE, ...) scale_fill_californication(n, type = "discrete", reverse = FALSE, ...)californication_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_californication(n, type = "discrete", reverse = FALSE, ...) scale_colour_californication(n, type = "discrete", reverse = FALSE, ...) scale_fill_californication(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(californication_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_californication() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_californication() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_californication()library(scales) show_col(californication_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_californication() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_californication() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_californication()
coltrane palette
coltrane_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_coltrane(n, type = "discrete", reverse = FALSE, ...) scale_colour_coltrane(n, type = "discrete", reverse = FALSE, ...) scale_fill_coltrane(n, type = "discrete", reverse = FALSE, ...)coltrane_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_coltrane(n, type = "discrete", reverse = FALSE, ...) scale_colour_coltrane(n, type = "discrete", reverse = FALSE, ...) scale_fill_coltrane(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(coltrane_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_coltrane() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_coltrane() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_coltrane()library(scales) show_col(coltrane_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_coltrane() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_coltrane() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_coltrane()
deelite palette
deelite_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_deelite(n, type = "discrete", reverse = FALSE, ...) scale_colour_deelite(n, type = "discrete", reverse = FALSE, ...) scale_fill_deelite(n, type = "discrete", reverse = FALSE, ...)deelite_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_deelite(n, type = "discrete", reverse = FALSE, ...) scale_colour_deelite(n, type = "discrete", reverse = FALSE, ...) scale_fill_deelite(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(deelite_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_deelite() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_deelite() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_deelite()library(scales) show_col(deelite_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_deelite() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_deelite() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_deelite()
Alice In Chains - Dirt palette
dirt_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_dirt(n, type = "discrete", reverse = FALSE, ...) scale_colour_dirt(n, type = "discrete", reverse = FALSE, ...) scale_fill_dirt(n, type = "discrete", reverse = FALSE, ...)dirt_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_dirt(n, type = "discrete", reverse = FALSE, ...) scale_colour_dirt(n, type = "discrete", reverse = FALSE, ...) scale_fill_dirt(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(dirt_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_dirt() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_dirt() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_dirt()library(scales) show_col(dirt_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_dirt() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_dirt() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_dirt()
electric palette
electric_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_electric(n, type = "discrete", reverse = FALSE, ...) scale_colour_electric(n, type = "discrete", reverse = FALSE, ...) scale_fill_electric(n, type = "discrete", reverse = FALSE, ...)electric_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_electric(n, type = "discrete", reverse = FALSE, ...) scale_colour_electric(n, type = "discrete", reverse = FALSE, ...) scale_fill_electric(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(electric_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_electric() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_electric() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_electric()library(scales) show_col(electric_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_electric() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_electric() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_electric()
facelift palette
facelift_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_facelift(n, type = "discrete", reverse = FALSE, ...) scale_colour_facelift(n, type = "discrete", reverse = FALSE, ...) scale_fill_facelift(n, type = "discrete", reverse = FALSE, ...)facelift_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_facelift(n, type = "discrete", reverse = FALSE, ...) scale_colour_facelift(n, type = "discrete", reverse = FALSE, ...) scale_fill_facelift(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(facelift_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_facelift() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_facelift() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_facelift()library(scales) show_col(facelift_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_facelift() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_facelift() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_facelift()
harvey palette
harvey_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_harvey(n, type = "discrete", reverse = FALSE, ...) scale_colour_harvey(n, type = "discrete", reverse = FALSE, ...) scale_fill_harvey(n, type = "discrete", reverse = FALSE, ...)harvey_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_harvey(n, type = "discrete", reverse = FALSE, ...) scale_colour_harvey(n, type = "discrete", reverse = FALSE, ...) scale_fill_harvey(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(harvey_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_harvey() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_harvey() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_harvey()library(scales) show_col(harvey_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_harvey() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_harvey() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_harvey()
heep palette
heep_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_heep(n, type = "discrete", reverse = FALSE, ...) scale_colour_heep(n, type = "discrete", reverse = FALSE, ...) scale_fill_heep(n, type = "discrete", reverse = FALSE, ...)heep_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_heep(n, type = "discrete", reverse = FALSE, ...) scale_colour_heep(n, type = "discrete", reverse = FALSE, ...) scale_fill_heep(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(heep_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_heep() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_heep() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_heep()library(scales) show_col(heep_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_heep() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_heep() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_heep()
hellawaits palette
hellawaits_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_hellawaits(n, type = "discrete", reverse = FALSE, ...) scale_colour_hellawaits(n, type = "discrete", reverse = FALSE, ...) scale_fill_hellawaits(n, type = "discrete", reverse = FALSE, ...)hellawaits_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_hellawaits(n, type = "discrete", reverse = FALSE, ...) scale_colour_hellawaits(n, type = "discrete", reverse = FALSE, ...) scale_fill_hellawaits(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(hellawaits_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_hellawaits() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_hellawaits() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_hellawaits()library(scales) show_col(hellawaits_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_hellawaits() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_hellawaits() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_hellawaits()
husker palette
husker_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_husker(n, type = "discrete", reverse = FALSE, ...) scale_colour_husker(n, type = "discrete", reverse = FALSE, ...) scale_fill_husker(n, type = "discrete", reverse = FALSE, ...)husker_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_husker(n, type = "discrete", reverse = FALSE, ...) scale_colour_husker(n, type = "discrete", reverse = FALSE, ...) scale_fill_husker(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(husker_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_husker() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_husker() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_husker()library(scales) show_col(husker_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_husker() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_husker() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_husker()
janelle palette
janelle_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_janelle(n, type = "discrete", reverse = FALSE, ...) scale_colour_janelle(n, type = "discrete", reverse = FALSE, ...) scale_fill_janelle(n, type = "discrete", reverse = FALSE, ...)janelle_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_janelle(n, type = "discrete", reverse = FALSE, ...) scale_colour_janelle(n, type = "discrete", reverse = FALSE, ...) scale_fill_janelle(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(janelle_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_janelle() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_janelle() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_janelle()library(scales) show_col(janelle_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_janelle() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_janelle() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_janelle()
Led Zeppelin - Celebration Day colour palette
ledzep_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_ledzep(n, type = "discrete", reverse = FALSE, ...) scale_colour_ledzep(n, type = "discrete", reverse = FALSE, ...) scale_fill_ledzep(n, type = "discrete", reverse = FALSE, ...)ledzep_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_ledzep(n, type = "discrete", reverse = FALSE, ...) scale_colour_ledzep(n, type = "discrete", reverse = FALSE, ...) scale_fill_ledzep(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(ledzep_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_ledzep() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_ledzep() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_ledzep()library(scales) show_col(ledzep_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_ledzep() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_ledzep() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_ledzep()
melloncollie palette
melloncollie_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_melloncollie(n, type = "discrete", reverse = FALSE, ...) scale_colour_melloncollie(n, type = "discrete", reverse = FALSE, ...) scale_fill_melloncollie(n, type = "discrete", reverse = FALSE, ...)melloncollie_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_melloncollie(n, type = "discrete", reverse = FALSE, ...) scale_colour_melloncollie(n, type = "discrete", reverse = FALSE, ...) scale_fill_melloncollie(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(melloncollie_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_melloncollie() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_melloncollie() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_melloncollie()library(scales) show_col(melloncollie_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_melloncollie() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_melloncollie() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_melloncollie()
miles palette
miles_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_miles(n, type = "discrete", reverse = FALSE, ...) scale_colour_miles(n, type = "discrete", reverse = FALSE, ...) scale_fill_miles(n, type = "discrete", reverse = FALSE, ...)miles_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_miles(n, type = "discrete", reverse = FALSE, ...) scale_colour_miles(n, type = "discrete", reverse = FALSE, ...) scale_fill_miles(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(miles_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_miles() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_miles() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_miles()library(scales) show_col(miles_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_miles() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_miles() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_miles()
muse palette
muse_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_muse(n, type = "discrete", reverse = FALSE, ...) scale_colour_muse(n, type = "discrete", reverse = FALSE, ...) scale_fill_muse(n, type = "discrete", reverse = FALSE, ...)muse_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_muse(n, type = "discrete", reverse = FALSE, ...) scale_colour_muse(n, type = "discrete", reverse = FALSE, ...) scale_fill_muse(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(muse_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_muse() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_muse() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_muse()library(scales) show_col(muse_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_muse() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_muse() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_muse()
nodoubt palette
nodoubt_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_nodoubt(n, type = "discrete", reverse = FALSE, ...) scale_colour_nodoubt(n, type = "discrete", reverse = FALSE, ...) scale_fill_nodoubt(n, type = "discrete", reverse = FALSE, ...)nodoubt_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_nodoubt(n, type = "discrete", reverse = FALSE, ...) scale_colour_nodoubt(n, type = "discrete", reverse = FALSE, ...) scale_fill_nodoubt(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(nodoubt_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_nodoubt() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_nodoubt() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_nodoubt()library(scales) show_col(nodoubt_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_nodoubt() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_nodoubt() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_nodoubt()
peacesells palette
peacesells_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_peacesells(n, type = "discrete", reverse = FALSE, ...) scale_colour_peacesells(n, type = "discrete", reverse = FALSE, ...) scale_fill_peacesells(n, type = "discrete", reverse = FALSE, ...)peacesells_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_peacesells(n, type = "discrete", reverse = FALSE, ...) scale_colour_peacesells(n, type = "discrete", reverse = FALSE, ...) scale_fill_peacesells(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(peacesells_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_peacesells() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_peacesells() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_peacesells()library(scales) show_col(peacesells_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_peacesells() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_peacesells() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_peacesells()
real_thing palette
real_thing_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_real_thing(n, type = "discrete", reverse = FALSE, ...) scale_colour_real_thing(n, type = "discrete", reverse = FALSE, ...) scale_fill_real_thing(n, type = "discrete", reverse = FALSE, ...)real_thing_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_real_thing(n, type = "discrete", reverse = FALSE, ...) scale_colour_real_thing(n, type = "discrete", reverse = FALSE, ...) scale_fill_real_thing(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(real_thing_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_real_thing() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_real_thing() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_real_thing()library(scales) show_col(real_thing_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_real_thing() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_real_thing() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_real_thing()
R package that contains color palettes based on colours on classic rock album covers.
rock_palette(name, n, type = c("discrete", "continuous"))rock_palette(name, n, type = c("discrete", "continuous"))
name |
Name of palette. Select one:
|
n |
Number of colors desired. Some palettes contain 5 colors. Those beginning with 'rock' have 4 |
type |
Either continuous or discrete. |
See also: https://github.com/johnmackintosh/metallicaRt for metallica palettes
A vector of colors.
rock_palette("swift")rock_palette("swift")
Muse Second Law Palette
second_law_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_second_law(n, type = "discrete", reverse = FALSE, ...) scale_colour_second_law(n, type = "discrete", reverse = FALSE, ...) scale_fill_second_law(n, type = "discrete", reverse = FALSE, ...)second_law_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_second_law(n, type = "discrete", reverse = FALSE, ...) scale_colour_second_law(n, type = "discrete", reverse = FALSE, ...) scale_fill_second_law(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(second_law_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_second_law() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_second_law() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_second_law()library(scales) show_col(second_law_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_second_law() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_second_law() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_second_law()
siamesedream palette
siamesedream_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_siamesedream(n, type = "discrete", reverse = FALSE, ...) scale_colour_siamesedream(n, type = "discrete", reverse = FALSE, ...) scale_fill_siamesedream(n, type = "discrete", reverse = FALSE, ...)siamesedream_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_siamesedream(n, type = "discrete", reverse = FALSE, ...) scale_colour_siamesedream(n, type = "discrete", reverse = FALSE, ...) scale_fill_siamesedream(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(siamesedream_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_siamesedream() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_siamesedream() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_siamesedream()library(scales) show_col(siamesedream_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_siamesedream() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_siamesedream() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_siamesedream()
taylor palette
taylor_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_taylor(n, type = "discrete", reverse = FALSE, ...) scale_colour_taylor(n, type = "discrete", reverse = FALSE, ...) scale_fill_taylor(n, type = "discrete", reverse = FALSE, ...)taylor_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_taylor(n, type = "discrete", reverse = FALSE, ...) scale_colour_taylor(n, type = "discrete", reverse = FALSE, ...) scale_fill_taylor(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(taylor_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_taylor() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_taylor() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_taylor()library(scales) show_col(taylor_pal()(10)) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_taylor() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_taylor() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_taylor()